@@ -27,6 +27,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_ec2
@@ -71,6 +73,9 @@ class ApplicationLoadBalancerEndpoint(
         :param preserve_client_ip: Forward the client IP address in an ``X-Forwarded-For`` header. GlobalAccelerator will create Network Interfaces in your VPC in order to preserve the client IP address. Client IP address preservation is supported only in specific AWS Regions. See the GlobalAccelerator Developer Guide for a list. Default: true if available
         :param weight: Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ApplicationLoadBalancerEndpoint.__init__)
+            check_type(argname="argument load_balancer", value=load_balancer, expected_type=type_hints["load_balancer"])
         options = ApplicationLoadBalancerEndpointOptions(
             preserve_client_ip=preserve_client_ip, weight=weight
         )
@@ -82,7 +87,7 @@ class ApplicationLoadBalancerEndpoint(
         '''Render the endpoint to an endpoint configuration.'''
         return typing.cast(typing.Any, jsii.invoke(self, "renderEndpointConfiguration", []))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="region")
     def region(self) -> typing.Optional[builtins.str]:
         '''The region where the endpoint is located.
@@ -126,6 +131,10 @@ class ApplicationLoadBalancerEndpointOptions:
                 ]
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ApplicationLoadBalancerEndpointOptions.__init__)
+            check_type(argname="argument preserve_client_ip", value=preserve_client_ip, expected_type=type_hints["preserve_client_ip"])
+            check_type(argname="argument weight", value=weight, expected_type=type_hints["weight"])
         self._values: typing.Dict[str, typing.Any] = {}
         if preserve_client_ip is not None:
             self._values["preserve_client_ip"] = preserve_client_ip
@@ -204,6 +213,9 @@ class CfnEipEndpoint(
         :param eip: -
         :param weight: Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnEipEndpoint.__init__)
+            check_type(argname="argument eip", value=eip, expected_type=type_hints["eip"])
         options = CfnEipEndpointProps(weight=weight)
 
         jsii.create(self.__class__, self, [eip, options])
@@ -213,7 +225,7 @@ class CfnEipEndpoint(
         '''Render the endpoint to an endpoint configuration.'''
         return typing.cast(typing.Any, jsii.invoke(self, "renderEndpointConfiguration", []))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="region")
     def region(self) -> typing.Optional[builtins.str]:
         '''The region where the endpoint is located.
@@ -250,6 +262,9 @@ class CfnEipEndpointProps:
                 ]
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnEipEndpointProps.__init__)
+            check_type(argname="argument weight", value=weight, expected_type=type_hints["weight"])
         self._values: typing.Dict[str, typing.Any] = {}
         if weight is not None:
             self._values["weight"] = weight
@@ -314,6 +329,9 @@ class InstanceEndpoint(
         :param preserve_client_ip: Forward the client IP address. GlobalAccelerator will create Network Interfaces in your VPC in order to preserve the client IP address. Client IP address preservation is supported only in specific AWS Regions. See the GlobalAccelerator Developer Guide for a list. Default: true if available
         :param weight: Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(InstanceEndpoint.__init__)
+            check_type(argname="argument instance", value=instance, expected_type=type_hints["instance"])
         options = InstanceEndpointProps(
             preserve_client_ip=preserve_client_ip, weight=weight
         )
@@ -325,7 +343,7 @@ class InstanceEndpoint(
         '''Render the endpoint to an endpoint configuration.'''
         return typing.cast(typing.Any, jsii.invoke(self, "renderEndpointConfiguration", []))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="region")
     def region(self) -> typing.Optional[builtins.str]:
         '''The region where the endpoint is located.
@@ -369,6 +387,10 @@ class InstanceEndpointProps:
                 ]
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(InstanceEndpointProps.__init__)
+            check_type(argname="argument preserve_client_ip", value=preserve_client_ip, expected_type=type_hints["preserve_client_ip"])
+            check_type(argname="argument weight", value=weight, expected_type=type_hints["weight"])
         self._values: typing.Dict[str, typing.Any] = {}
         if preserve_client_ip is not None:
             self._values["preserve_client_ip"] = preserve_client_ip
@@ -463,6 +485,9 @@ class NetworkLoadBalancerEndpoint(
         :param load_balancer: -
         :param weight: Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(NetworkLoadBalancerEndpoint.__init__)
+            check_type(argname="argument load_balancer", value=load_balancer, expected_type=type_hints["load_balancer"])
         options = NetworkLoadBalancerEndpointProps(weight=weight)
 
         jsii.create(self.__class__, self, [load_balancer, options])
@@ -472,7 +497,7 @@ class NetworkLoadBalancerEndpoint(
         '''Render the endpoint to an endpoint configuration.'''
         return typing.cast(typing.Any, jsii.invoke(self, "renderEndpointConfiguration", []))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="region")
     def region(self) -> typing.Optional[builtins.str]:
         '''The region where the endpoint is located.
@@ -509,6 +534,9 @@ class NetworkLoadBalancerEndpointProps:
                 ]
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(NetworkLoadBalancerEndpointProps.__init__)
+            check_type(argname="argument weight", value=weight, expected_type=type_hints["weight"])
         self._values: typing.Dict[str, typing.Any] = {}
         if weight is not None:
             self._values["weight"] = weight
